Coverage for src\pqlattice\random\_lwe.py: 71%

1 from typing import overload

2

3 from ..typing import Matrix, Vector

4

5

6 class LWE:

7 def __init__(self):

8 """_summary_

9

10 Raises

11 ------

12 NotImplementedError

13 _description_

14 """

15 raise NotImplementedError()

16

17 @overload

18 def __call__(self, n: int) -> Matrix: ...

19

20 @overload

21 def __call__(self, n: None) -> Vector: ...

22

23 def __call__(self, n: int | None = None) -> Matrix | Vector:

24 """_summary_

25

26 Parameters

27 ----------

28 n : int | None, optional

29 _description_, by default None

30

31 Returns

32 -------

33 Matrix | Vector

34 _description_

35

36 Raises

37 ------

38 NotImplementedError

39 _description_

40 """

41 raise NotImplementedError()